@@ -33,7 +33,7 @@ CREATE TABLE autoreg_host (
         host            nvarchar2(64)           DEFAULT ''      ,
         PRIMARY KEY (autoreg_hostid)
 );
-CREATE UNIQUE INDEX autoreg_host_1 on autoreg_host (proxy_hostid,host);
+CREATE INDEX autoreg_host_1 on autoreg_host (proxy_hostid,host);
 alter table conditions modify value           nvarchar2(255)          DEFAULT '';
 alter table config add dropdown_first_entry number(10) DEFAULT '1' NOT NULL;
 alter table config add dropdown_first_remember number(10) DEFAULT '1' NOT NULL;
@@ -183,6 +183,7 @@ insert into help_items values (3,'smtp_perf&lt;,port&gt;','Checks if SMTP server
 insert into help_items values (3,'ssh_perf&lt;,port&gt;','Checks if SSH server is running and accepting connections. 0 - SSH server is down. Otherwise, number of seconds spent connecting to SSH server.');
 insert into help_items values (3,'tcp_perf,port','Checks if TCP service is running and accepting connections on port. 0 - the service on the port is down. Otherwise, number of seconds spent connecting to TCP service.');
 
+insert into help_items values (5,'zabbix[boottime]','Startup time of Zabbix server, Unix timestamp.');
 insert into help_items values (5,'zabbix[history]','Number of values stored in table HISTORY.');
 insert into help_items values (5,'zabbix[history_log]','Number of values stored in table HISTORY_LOG.');
 insert into help_items values (5,'zabbix[history_str]','Number of values stored in table HISTORY_STR.');
@@ -191,10 +192,15 @@ insert into help_items values (5,'zabbix[history_uint]','Number of values stored
 insert into help_items values (5,'zabbix[items]','Number of items in Zabbix database.');
 insert into help_items values (5,'zabbix[items_unsupported]','Number of unsupported items in Zabbix database.');
 insert into help_items values (5,'zabbix[log]','Stores warning and error messages generated by Zabbix server.');
+insert into help_items values (5,'zabbix[proxy,&lt;name&gt;,&lt;param&gt;]','Time of proxy last access. Name - proxy name. Param - lastaccess. Unix timestamp.');
 insert into help_items values (5,'zabbix[queue&lt;,from&gt;&lt;,to&gt;]','Number of items in the queue which are delayed by from to to seconds, inclusive.');
+insert into help_items values (5,'zabbix[rcache,&lt;cache&gt;,&lt;mode&gt;]','Configuration cache statistics. Cache - buffer (modes: pfree, total, used, free).');
 insert into help_items values (5,'zabbix[trends]','Number of values stored in table TRENDS.');
 insert into help_items values (5,'zabbix[trends_uint]','Number of values stored in table TRENDS_UINT.');
 insert into help_items values (5,'zabbix[triggers]','Number of triggers in Zabbix database.');
+insert into help_items values (5,'zabbix[uptime]','Uptime of Zabbix server process in seconds.');
+insert into help_items values (5,'zabbix[wcache,&lt;cache&gt;,&lt;mode&gt;]','Data cache statistics. Cache - one of values (modes: all, float, uint, str, log, text), history (modes: pfree, total, used, free), trend (modes: pfree, total, used, free), text (modes: pfree, total, used, free).');
+insert into help_items values (5,'zabbix[process,&lt;type&gt;,&lt;num&gt;,&lt;state&gt;]','Time a particular Zabbix process or a group of processes (identified by &lt;type&gt; and &lt;num&gt;) spent in &lt;state&gt; in percentage.');
 
 insert into help_items values (8,'grpfunc[&lt;Group&gt;,&lt;Key&gt;,&lt;func&gt;,&lt;param&gt;]','Aggregate checks do not require any agent running on a host being monitored. Zabbix server collects aggregate information by doing direct database queries. See Zabbix Manual.');
 
@@ -205,6 +211,8 @@ insert into help_items values(0,'kernel.maxproc','Maximum number of processes su
 insert into help_items values(0,'net.if.collisions[if]','Out-of-window collision. Collisions count.');
 insert into help_items values(0,'net.if.in[if &lt;,mode&gt;]','Network interface input statistic. Integer value. If mode is missing bytes is used.');
 insert into help_items values(0,'net.if.out[if &lt;,mode&gt;]','Network interface output statistic. Integer value. If mode is missing bytes is used.');
+insert into help_items values(0,'net.if.total[if &lt;,mode&gt;]','Sum of network interface incoming and outgoing statistics. Integer value. Mode - one of bytes (default), packets, errors or dropped');
+insert into help_items values(0,'net.if.list','List of network interfaces. Text value.');
 insert into help_items values(0,'net.tcp.dns[ip, zone]','Checks if DNS service is up. 0 - DNS is down, 1 - DNS is up.');
 insert into help_items values(0,'net.tcp.dns.query[ip, zone, type]','Performs a query for the record type specified by the parameter type');
 insert into help_items values(0,'net.tcp.listen[port]','Checks if this port is in LISTEN state. 0 - it is not, 1 - it is in LISTEN state.');
@@ -219,7 +227,7 @@ insert into help_items values(0,'system.cpu.switches','Context switches.');
 insert into help_items values(0,'system.cpu.util[&lt;cpu&gt; &lt;,type&gt; &lt;,mode&gt;]','CPU(s) utilisation. Processor load in percents. The cpu, type and mode are optional. If cpu is missing all is used.  If type is missing user is used. If mode is missing avg1 is used.');
 insert into help_items values(0,'system.boottime','Timestamp of system boot.');
 insert into help_items values(0,'system.cpu.num','Number of available proccessors.');
-insert into help_items values(0,'system.hostname','Return host name. String value. Example of returned value: www.zabbix.com');
+insert into help_items values(0,'system.hostname[&lt;type&gt;]','Returns hostname (or NetBIOS name (by default) on Windows). String value. Example of returned value: www.zabbix.com');
 insert into help_items values(0,'system.localtime','System local time. Time in seconds.');
 insert into help_items values(0,'system.run[command,&lt;mode&gt]','Run specified command on the host.');
 insert into help_items values(0,'system.swap.in[&lt;swap&gt; &lt;,type&gt;]','Swap in. If type is count - swapins is returned. If type is pages - pages swapped in is returned. If swap is missing all is used.');
@@ -236,16 +244,17 @@ insert into help_items values(0,'vfs.file.md5sum[file]','Calculate MD5 check sum
 insert into help_items values(0,'vfs.file.regexp[file,regexp]','Find string in a file. Matched string');
 insert into help_items values(0,'vfs.file.regmatch[file,regexp]','Find string in a file. 0 - expression not found, 1 - found');
 insert into help_items values(0,'vfs.file.size[file]','Size of a given file. Size in bytes. File must have read permissions for user zabbix. Example: vfs.file.size[/var/log/syslog]');
-insert into help_items values(0,'vfs.file.time[file&lt;, mode&gt;]','File time information. Number of seconds.	The mode is optional. If mode is missing modify is used.');
+insert into help_items values(0,'vfs.file.time[file &lt;,mode&gt;]','File time information. Number of seconds.	The mode is optional. If mode is missing modify is used.');
 insert into help_items values(0,'vfs.fs.inode[fs &lt;,mode&gt;]','Number of inodes for a given volume. If mode is missing total is used.');
 insert into help_items values(0,'vfs.fs.size[fs &lt;,mode&gt;]','Calculate disk space for a given volume. Disk space in KB. If mode is missing total is used.  In case of mounted volume, unused disk space for local file system is returned. Example: vfs.fs.size[/tmp,free].');
 insert into help_items values(0,'vm.memory.size[&lt;mode&gt;]','Amount of memory size in bytes. If mode is missing total is used.');
 insert into help_items values(0,'web.page.get[host,&lt;path&gt;,&lt;port&gt;]','Get content of WEB page. Default path is /');
 insert into help_items values(0,'web.page.perf[host,&lt;path&gt;,&lt;port&gt;]','Get timing of loading full WEB page. Default path is /');
 insert into help_items values(0,'web.page.regexp[host,&lt;path&gt;,&lt;port&gt;,&lt;regexp&gt;,&lt;length&gt;]','Get first occurence of regexp in WEB page. Default path is /');
-insert into help_items values(0,'perf_counter[counter]','Value of any performance counter, where parameter is the counter path.');
+insert into help_items values(0,'perf_counter[counter, interval]','Value of any performance counter, where "counter" parameter is the counter path and "interval" parameter is a number of last seconds, for which the agent returns an average value.');
 insert into help_items values(0,'service_state[service]','State of service. 0 - running, 1 - paused, 2 - start pending, 3 - pause pending, 4 - continue pending, 5 - stop pending, 6 - stopped, 7 - unknown, 255 - no such service');
 insert into help_items values(0,'proc_info[&lt;process&gt;,&lt;attribute&gt;,&lt;type&gt;]','Different information about specific process(es)');
+insert into help_items values(0,'system.stat[resource &lt;,type&gt;]','Virtual memory statistics.');
 
 insert into help_items values(7,'agent.ping','Check the agent usability. Always return 1. Can be used as a TCP ping.');
 insert into help_items values(7,'agent.version','Version of zabbix_agent(d) running on monitored host. String value. Example of returned value: 1.1');
@@ -254,6 +263,8 @@ insert into help_items values(7,'kernel.maxproc','Maximum number of processes su
 insert into help_items values(7,'net.if.collisions[if]','Out-of-window collision. Collisions count.');
 insert into help_items values(7,'net.if.in[if &lt;,mode&gt;]','Network interface input statistic. Integer value. If mode is missing bytes is used.');
 insert into help_items values(7,'net.if.out[if &lt;,mode&gt;]','Network interface output statistic. Integer value. If mode is missing bytes is used.');
+insert into help_items values(7,'net.if.total[if &lt;,mode&gt;]','Sum of network interface incoming and outgoing statistics. Integer value. Mode - one of bytes (default), packets, errors or dropped');
+insert into help_items values(7,'net.if.list','List of network interfaces. Text value.');
 insert into help_items values(7,'net.tcp.dns[ip, zone]','Checks if DNS service is up. 0 - DNS is down, 1 - DNS is up.');
 insert into help_items values(7,'net.tcp.dns.query[ip, zone, type]','Performs a query for the record type specified by the parameter type');
 insert into help_items values(7,'net.tcp.listen[port]','Checks if this port is in LISTEN state. 0 - it is not, 1 - it is in LISTEN state.');
@@ -268,7 +279,7 @@ insert into help_items values(7,'system.cpu.switches','Context switches.');
 insert into help_items values(7,'system.cpu.util[&lt;cpu&gt; &lt;,type&gt; &lt;,mode&gt;]','CPU(s) utilisation. Processor load in percents. The cpu, type and mode are optional. If cpu is missing all is used.  If type is missing user is used. If mode is missing avg1 is used.');
 insert into help_items values(7,'system.boottime','Timestamp of system boot.');
 insert into help_items values(7,'system.cpu.num','Number of available proccessors.');
-insert into help_items values(7,'system.hostname','Return host name. String value. Example of returned value: www.zabbix.com');
+insert into help_items values(7,'system.hostname[&lt;type&gt;]','Returns hostname (or NetBIOS name (by default) on Windows). String value. Example of returned value: www.zabbix.com');
 insert into help_items values(7,'system.localtime','System local time. Time in seconds.');
 insert into help_items values(7,'system.run[command,&lt;mode&gt]','Run specified command on the host.');
 insert into help_items values(7,'system.swap.in[&lt;swap&gt; &lt;,type&gt;]','Swap in. If type is count - swapins is returned. If type is pages - pages swapped in is returned. If swap is missing all is used.');
@@ -298,6 +309,7 @@ insert into help_items values(7,'proc_info[&lt;process&gt;,&lt;attribute&gt;,&lt
 insert into help_items values(7,'log[file,&lt;pattern&gt;,&lt;encoding&gt;,&lt;maxlines&gt;]','Monitoring of log file. pattern - regular expression');
 insert into help_items values(7,'logrt[file_format,&lt;pattern&gt;,&lt;encoding&gt;,&lt;maxlines&gt;]', 'Monitoring of log file with rotation. fileformat - [path][regexp], pattern - regular expression');
 insert into help_items values(7,'eventlog[logtype,&lt;pattern&gt;,&lt;severity&gt;,&lt;source&gt;,&lt;eventid&gt;,&lt;maxlines&gt;]','Monitoring of Windows event logs. pattern, severity, eventid - regular expressions');
+insert into help_items values(7,'system.stat[resource &lt;,type&gt;]','Virtual memory statistics.');
 alter table history_log add logeventid              number(10)         DEFAULT '0'     NOT NULL;
 
 CREATE TABLE history_log_tmp (
@@ -481,6 +493,7 @@ alter table hosts modify ipmi_username           nvarchar2(16)           DEFAULT
 alter table hosts modify ipmi_password           nvarchar2(20)           DEFAULT '';
 alter table hosts modify ipmi_ip         nvarchar2(64)           DEFAULT '127.0.0.1';
 
+CREATE INDEX hosts_templates_2 on hosts_templates (templateid);
 alter table housekeeper modify tablename               nvarchar2(64)           DEFAULT '';
 alter table housekeeper modify field           nvarchar2(64)           DEFAULT '';
 alter table httpstep modify name            nvarchar2(64)           DEFAULT '';
